==> nextcloud-28.0.3.tgz: nextcloud/apps/text/l10n/mk.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Нова текстуална датотека",
    "Create new text file" : "Креирај нова текстуална датотека",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која е одредена во HTML формата",
    "The file was only partially uploaded" : "Датотеката е само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
    "Nextcloud Text" : "Текст",
    "text document" : "текстуален документ",
    "{user} has mentioned you in the text document {node}" : "{user} те спомна во текстуална датотека {node}",
    "Readme" : "Прочитај",
    "Text" : "Текст",
    "📝 Collaborative document editing" : "📝 Колаборативно уредување на документи",
    "Translate" : "Преведи",
    "Delete task" : "Избриши задача",
    "Use current version" : "Користи ја моменталната верзија",
    "Use the saved version" : "Користи ја зачуваната верзија",
    "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
    "Reconnect" : "Повторно поврзување",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Документот не е изменет од уредникот. Промените не можат да се применат.",
    "File could not be loaded. Please check your internet connection." : "Датотеката неможе да се вчита. Проверете ја вашата интернет врска.",
    "This file is opened read-only as it is currently locked by {user}." : "Оваа датотека е отворена како за читање и истата е заклучена од {user}.",
    "Close outline view" : "Затвори преглед",
    "Outline" : "Преглед",
    "Enter your name so other people can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
    "Edit guest name" : "Промени име на гостин",
    "Guest" : "Гостин",
    "Save guest name" : "Зачувај име на гостин",
    "Insert an attachment" : "Вметни прилог",
    "guest" : "гостин",
    "Show author colors" : "Прикажи ги боите на авторот",
    "Author colors are only shown until everyone has closed the document." : "Боите на авторот се прикажуваат само кога сите ќе го затворат документот.",
    "Active people" : "Активни луѓе",
    "Save document" : "Зачувај документ",
    "Last saved" : "Последно зачувано",
    "Offline" : "Исклучен",
    "Saving …" : "Зачувува ...",
    "Saved" : "Зачувано",
    "Last saved {lastSave}" : "Последно зачувано {lastSave}",
    "Unsaved changes" : "Незачувани промени",
    "Formatting help" : "Помош за форматирање",
    "Speed up your writing with simple shortcuts." : "Забрзајте го вашето пишување со овие едноставни кратенки.",
    "Style" : "Стил",
    "Syntax" : "Синтакса",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Shift" : "Shift",
    "Bold" : "Болд",
    "Bold text" : "Болдиран текст",
    "Ctrl" : "Ctrl",
    "Italic" : "Италик",
    "Strikethrough" : "Прецртај",
    "Mistaken text" : "Погрешен текст",
    "Underline" : "Подвлечен",
    "Underlined text" : "Подвлечен текст",
    "Heading 1" : "Заглавие 1",
    "Heading 6" : "Заглавие 6",
    "Unordered list" : "Неподредена листа",
    "Ordered list" : "Подредена листа",
    "Quoted text" : "Цитиран текст",
    "Some code" : "Некој код",
    "Save changes" : "Зачувај ги промените",
    "Cancel" : "Откажи",
    "URL" : "Адреса",
    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "Upload from computer" : "Прикачи од компјутер",
    "Insert from Files" : "Вметни од датотеките",
    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
    "Editor actions" : "Акции на уредникот",
    "Select language" : "Изберете јазик",
    "to" : "до",
    "Replace" : "Преклопи",
    "No emoji found" : "Не се пронајдени емотикони",
    "Source code" : "Изворен код",
    "Failed to load" : "Неуспешно вчитување",
    "Add row before" : "Додади ред пред",
    "Add row after" : "Додади ред после",
    "Delete this row" : "Избриши го овој ред",
    "Add column before" : "Додади колона пред",
    "Add column after" : "Додади колона после",
    "Delete this column" : "Избриши ја оваа колона",
    "Delete this table" : "Избриши ја оваа табела",
    "Undo" : "Назад",
    "Redo" : "Напред",
    "Headings" : "Заглавија",
    "Heading 2" : "Заглавие 2",
    "Heading 3" : "Заглавие 3",
    "Heading 4" : "Заглавие 4",
    "Heading 5" : "Заглавие 5",
    "Info" : "Инфо",
    "Success" : "Успешно",
    "Warning" : "Предупредување",
    "Table" : "Табела",
    "Insert emoji" : "Вметни емотикон",
    "Command" : "Команда",
    "Control" : "Контрола",
    "Option" : "Опции",
    "Add notes, lists or links …" : "Додади белешки, листи или линкови ...",
    "Edit" : "Уреди",
    "Add description" : "Додади опис",
    "Unsupported image type" : "Неподржан вид на слика",
    "Show rich workspaces" : "Прикажи збогатен работен простор"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-28.0.8.tgz: nextcloud/apps/text/l10n/mk.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која е одредена во HTML формата",
    "The file was only partially uploaded" : "Датотеката е само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "No file uploaded or file size exceeds maximum of %s" : "Нема прикачена дадотека или големината го надмминува максимумот од %s",
    "Nextcloud Text" : "Текст",
    "text document" : "текстуален документ",
    "New text file" : "Нова текстуална датотека",
    "Create new text file" : "Креирај нова текстуална датотека",
    "{user} has mentioned you in the text document {node}" : "{user} те спомна во текстуална датотека {node}",
    "File not found" : "Датотеката не е пронајдена",
    "Readme" : "Прочитај",
    "Text" : "Текст",
    "📝 Collaborative document editing" : "📝 Колаборативно уредување на документи",
    "Translate" : "Преведи",
    "Delete task" : "Избриши задача",
    "Use current version" : "Користи ја моменталната верзија",
    "Use the saved version" : "Користи ја зачуваната верзија",
    "Reconnect" : "Повторно поврзување",
    "Document idle for {timeout} minutes, click to continue editing" : "Документот е неактивен {timeout} минути, кликни за да продолжиш со уредување",
    "This file is opened read-only as it is currently locked by {user}." : "Оваа датотека е отворена како за читање и истата е заклучена од {user}.",
    "Close outline view" : "Затвори преглед",
    "Outline" : "Преглед",
    "Enter your name so other people can see who is editing" : "Напишете го вашето име за да можат другите корисници да знаат кој уредува",
    "Edit guest name" : "Промени име на гостин",
    "Guest" : "Гостин",
    "Save guest name" : "Зачувај име на гостин",
    "Insert an attachment" : "Вметни прилог",
    "guest" : "гостин",
    "Active people" : "Активни луѓе",
    "Save document" : "Зачувај документ",
    "Last saved" : "Последно зачувано",
    "Offline" : "Исклучен",
    "Saving …" : "Зачувува ...",
    "Saved" : "Зачувано",
    "Last saved {lastSave}" : "Последно зачувано {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Документот не е изменет од уредникот. Промените не можат да се применат.",
    "Unsaved changes" : "Незачувани промени",
    "Speed up your writing with simple shortcuts." : "Забрзајте го вашето пишување со овие едноставни кратенки.",
    "Style" : "Стил",
    "Syntax" : "Синтакса",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Shift" : "Shift",
    "Bold" : "Болд",
    "Bold text" : "Болдиран текст",
    "Ctrl" : "Ctrl",
    "Italic" : "Италик",
    "Strikethrough" : "Прецртај",
    "Mistaken text" : "Погрешен текст",
    "Underline" : "Подвлечен",
    "Underlined text" : "Подвлечен текст",
    "Heading 1" : "Заглавие 1",
    "Heading 6" : "Заглавие 6",
    "Unordered list" : "Неподредена листа",
    "Ordered list" : "Подредена листа",
    "Quoted text" : "Цитиран текст",
    "Some code" : "Некој код",
    "Link" : "Линк",
    "Insert emoji" : "Вметни емотикон",
    "Undo" : "Назад",
    "Redo" : "Напред",
    "Alt" : "Alt",
    "Save changes" : "Зачувај ги промените",
    "Cancel" : "Откажи",
    "URL" : "Адреса",
    "Cannot copy, please copy the link manually" : "Неможе да се копира, копирајте го линкот рачно",
    "Upload from computer" : "Прикачи од компјутер",
    "Insert from Files" : "Вметни од датотеките",
    "Formatting help" : "Помош за форматирање",
    "Select file or folder to link to" : "Изберете датотека или папка за линк до",
    "Editor actions" : "Акции на уредникот",
    "Select language" : "Изберете јазик",
    "to" : "до",
    "Replace" : "Преклопи",
    "No emoji found" : "Не се пронајдени емотикони",
    "Edit" : "Уреди",
    "Source code" : "Изворен код",
    "Failed to load" : "Неуспешно вчитување",
    "Add row before" : "Додади ред пред",
    "Add row after" : "Додади ред после",
    "Delete this row" : "Избриши го овој ред",
    "Add column before" : "Додади колона пред",
    "Add column after" : "Додади колона после",
    "Delete this column" : "Избриши ја оваа колона",
    "Delete this table" : "Избриши ја оваа табела",
    "Headings" : "Заглавија",
    "Heading 2" : "Заглавие 2",
    "Heading 3" : "Заглавие 3",
    "Heading 4" : "Заглавие 4",
    "Heading 5" : "Заглавие 5",
    "Info" : "Инфо",
    "Success" : "Успешно",
    "Warning" : "Предупредување",
    "Table" : "Табела",
    "Command" : "Команда",
    "Control" : "Контрола",
    "Option" : "Опции",
    "Add notes, lists or links …" : "Додади белешки, листи или линкови ...",
    "Show author colors" : "Прикажи ги боите на авторот",
    "Author colors are only shown until everyone has closed the document." : "Боите на авторот се прикажуваат само кога сите ќе го затворат документот.",
    "Show rich workspaces" : "Прикажи збогатен работен простор",
    "Add description" : "Додади опис"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
